@@ -83,6 +83,7 @@ new_mapping <- function(new = NULL, target, source = NULL, lut = NULL,
   assertDataFrame(x = lut, null.ok = TRUE)
   assertIntegerish(x = certainty, lower = 1, upper = 4)
   assertChoice(x = type, choices = c("concept", "class"))
+  assertCharacter(x = matchDir, null.ok = TRUE)
   assertLogical(x = verbose, len = 1)
 
   if(inherits(x = ontology, what = "onto")){
@@ -265,7 +266,7 @@ new_mapping <- function(new = NULL, target, source = NULL, lut = NULL,
       pivot_wider(id_cols = all_of(targetCols), names_from = match, values_from = newid)
 
     toOut <- toOut %>%
-      na_if(y = "") %>%
+      mutate(across(where(is.character), function(x) na_if(x, ""))) %>%
       select(all_of(targetCols), description, has_close_match, has_broader_match, has_narrower_match, has_exact_match) %>%
       arrange(id)
 
@@ -292,3 +293,5 @@ new_mapping <- function(new = NULL, target, source = NULL, lut = NULL,
   return(out)
 
 }
+
+utils::globalVariables("where")
